import { __awaiter } from "tslib";
import { assureDesignSystem, ResourceType, } from '@genesislcap/foundation-utils';
import { logger } from '../utils';
/**
 * @remarks
 * Attempts to use a module federation version of rapid before falling back to the version that was bundled with the app.
 * @internal
 */
function rapidDesignSystemImport() {
    return __awaiter(this, void 0, void 0, function* () {
        let module;
        let type = ResourceType.remote;
        try {
            module = yield import(
            /* webpackChunkName: "rapid-design-system" */
            'foundationRapid/RapidDesignSystem');
            return assureDesignSystem(module);
        }
        catch (e) {
            logger.info(`Please note remoteEntry.js load errors are expected if module federated dependencies are offline. Falling back to locally bundled versions.`);
            type = ResourceType.local;
            module = yield import(
            /* webpackChunkName: "rapid-design-system" */
            '@genesislcap/rapid-design-system');
            return assureDesignSystem(module);
        }
        finally {
            logger.debug(`Using '${type}' version of rapid-design-system`);
        }
    });
}
/**
 * @public
 */
export const registerCommonRapidComponents = () => __awaiter(void 0, void 0, void 0, function* () {
    const { provideDesignSystem, rapidIcon, rapidButton, designSystemProvider: rapidDesignSystemProvider, rapidSelect, rapidListboxOption, rapidFlyout, rapidConnectionIndicator, } = yield rapidDesignSystemImport();
    /**
     * Register the components the app is using with the system.
     */
    provideDesignSystem().register(
    /**
     * Design system provider element used to declaratively apply rapid config to every dom node in the host tree.
     */
    rapidDesignSystemProvider(), 
    /**
     * Common across most routes, so batch register these lightweight components upfront.
     */
    rapidIcon(), rapidButton(), rapidSelect(), rapidListboxOption(), rapidFlyout(), rapidConnectionIndicator);
});
